ArPlatformFactory class

Factory that returns the correct AR service for the current platform.

Constructors

ArPlatformFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isAvailable bool
Whether AR is available on this platform.
no setter
platformName String
Human-readable platform name.
no setter

Static Methods

create() ArService
Create the platform-appropriate AR service.