ArPlane class

Normalized detected plane from ARKit or ARCore.

ARKit: ARKitPlaneAnchor with center, extent, transform. ARCore: ArCorePlane with extendX, extendZ, centerPose.

Constructors

ArPlane({required String id, required ArPlaneType type, required ArPose centerPose, required double extentX, required double extentZ})
const

Properties

area double
Area of detected plane in m².
no setter
center → Vector3
Center position in world space.
no setter
centerPose ArPose
final
extentX double
final
extentZ double
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isSignificant bool
Whether this plane is large enough to be a wall/floor.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ArPlaneType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited