ArMeasureController class
Controller for AR measurement sessions.
Manages the measurement flow: tap to place points, calculate distance, assign to room dimensions (width/depth/height).
- Inheritance
-
- Object
- Listenable
- ListNotifier
- SintController
- ArMeasureController
Constructors
Properties
- arService ↔ ArService
-
latefinal
-
currentMeasurement
→ Rxn<
ArMeasurement> -
final
-
detectedPlanes
→ RxList<
ArPlane> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isArSupported → RxBool
-
final
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isDisposed → bool
-
no setterinherited
- isRoomComplete → bool
-
Whether all room dimensions have been assigned.
no setter
- listenersLength → int
-
no setterinherited
- measureService → ArMeasurementImpl
-
final
-
measureState
→ Rx<
ArMeasureState> -
final
-
roomDepth
→ Rxn<
double> -
final
-
roomHeight
→ Rxn<
double> -
final
- roomMeasurement → ArRoomMeasurement
-
Get the completed room measurement.
no setter
-
roomWidth
→ Rxn<
double> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scanPhase
→ Rx<
ArScanPhase> -
final
- statusMessage → RxString
-
final
Methods
-
addListener(
SintStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, SintStateUpdate listener) → Disposer -
inherited
-
assignToDepth(
) → void -
assignToHeight(
) → void -
assignToWidth(
) → void - Assign current measurement to a room dimension.
-
containsListener(
SintStateUpdate listener) → bool -
inherited
-
debounce<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void -
Calls
callbackafterrxstops changing forduration. Useful for search-as-you-type, form validation, etc.inherited -
dispose(
) → void -
inherited
-
ever<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackevery timerxchanges. Auto-cancels on controller disposal.inherited -
interval<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void -
Calls
callbackat most once perduration, ignoring intermediate changes. Useful for rate-limiting UI updates.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onArcoreHitResults(
List< ArHitResult> results) → void - Process ARCore hit results (called from ArCoreView.onPlaneTap).
-
once<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackonly the first timerxchanges, then cancels.inherited -
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
override
-
onDelete(
) → void -
inherited
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
onStart(
) → void -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
onTap(
double x, double y) → Future< void> - Handle a tap on the AR view.
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
reportAdd(
VoidCallback disposer) → void -
inherited
-
reportRead(
) → void -
inherited
-
reset(
) → void - Reset everything.
-
startMeasuring(
) → void - Start a new measurement session.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Notifies listeners to update the UI.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited